
export default function request(url, options) {
  // eslint-disable-next-line no-undef
  const prefix = (process.env.VUE_APP_SERVER || '') + '/api'
  
  const { timeout = 6000, ...opts } = options || {}

  const controller = new AbortController();
  const signal = controller.signal;
  const tid = setTimeout(() => controller.abort(), timeout);

  const resp = fetch(prefix + url, { signal, ...opts }).then(res => res.json()).then((res) => {
    clearTimeout(tid);
    if (res.code === 1000) {
      return res.data
    } else {
      return Promise.reject(res)
    }
  }).catch(err => {
    clearTimeout(tid);
    return Promise.reject(err);
  })

  return resp;
}

export function postJSON(url, options) {
  const { data, ...others } = options
  const newOpts = {
    method: 'POST',
    headers: {
      'Content-Type': 'application/json'
    },
    body: JSON.stringify(data),
    ...others,
  }

  return request(url, newOpts)
}
